@@ -1,13 +1,15 @@
 package Data::Verifier::Results;
 BEGIN {
-  $Data::Verifier::Results::VERSION = '0.43';
+  $Data::Verifier::Results::VERSION = '0.44';
 }
-
 use Moose;
 use MooseX::Storage;
 
 with 'MooseX::Storage::Deferred';
 
+# ABSTRACT: Results of a Data::Verifier verify
+
+
 has 'fields' => (
     is  => 'rw',
     isa => 'HashRef',
@@ -16,10 +18,11 @@ has 'fields' => (
     handles => {
         get_field => 'get',
         set_field => 'set',
-		has_field => 'exists'
+        has_field => 'exists'
     }
 );
 
+
 sub get_original_value {
     my ($self, $key) = @_;
 
@@ -28,6 +31,7 @@ sub get_original_value {
     return $f->original_value;
 }
 
+
 sub get_post_filter_value {
     my ($self, $key) = @_;
 
@@ -36,6 +40,7 @@ sub get_post_filter_value {
     return $f->post_filter_value;
 }
 
+
 sub get_value {
     my ($self, $key) = @_;
 
@@ -44,12 +49,14 @@ sub get_value {
     return $f->value;
 }
 
+
 sub get_values {
     my ($self, @keys) = @_;
 
     return map { $self->get_value($_) } @keys;
 }
 
+
 sub is_invalid {
     my ($self, $field) = @_;
 
@@ -59,6 +66,7 @@ sub is_invalid {
     return $f->valid ? 0 : 1;
 }
 
+
 sub is_missing {
     my ($self, $field) = @_;
 
@@ -70,6 +78,7 @@ sub is_missing {
     return 0;
 }
 
+
 sub is_valid {
     my ($self, $field) = @_;
 
@@ -79,6 +88,7 @@ sub is_valid {
     return $f->valid ? 1 : 0;
 }
 
+
 sub is_wrong {
     my ($self, $field) = @_;
 
@@ -101,12 +111,14 @@ sub merge {
     }
 }
 
+
 sub invalid_count {
     my ($self) = @_;
 
     return scalar($self->invalids);
 }
 
+
 sub invalids {
     my ($self) = @_;
 
@@ -116,12 +128,14 @@ sub invalids {
     );
 }
 
+
 sub missing_count {
     my ($self) = @_;
 
     return scalar($self->missings);
 }
 
+
 sub missings {
     my ($self) = @_;
 
@@ -131,6 +145,7 @@ sub missings {
     );
 }
 
+
 sub success {
     my ($self) = @_;
 
@@ -141,6 +156,7 @@ sub success {
     return 1;
 }
 
+
 sub valids {
     my ($self) = @_;
 
@@ -150,12 +166,14 @@ sub valids {
     );
 }
 
+
 sub valid_count {
     my ($self) = @_;
 
     return scalar($self->valids);
 }
 
+
 sub valid_values {
     my ($self) = @_;
 
@@ -166,11 +184,17 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-Data::Verifier::Results - Results of a Data::Verifier
+Data::Verifier::Results - Results of a Data::Verifier verify
+
+=head1 VERSION
+
+version 0.44
 
 =head1 SYNOPSIS
 
@@ -203,117 +227,6 @@ Data::Verifier::Results - Results of a Data::Verifier
     $results->is_missing('name'); # no
     $results->is_missing('sign'); # yes
 
-=head1 SUCCESS OR FAILURE
-
-=head2 success
-
-Returns true or false based on if the verification's success.
-
-=head2 is_wrong ($name)
-
-Returns true if the value was required and is missing or if the value did not
-pass it's type constraint.  This is a one-stop method for determining if the
-field in question is "wrong".
-
-=head1 VALUES
-
-The values present in the result are the filtered, valid values.  These may
-differ from the ones supplied to the verify method due to either filters
-or coercions.
-
-=head2 valid_count
-
-Returns the number of valid fields in this Results.
-
-=head2 valids
-
-Returns a list of valid field names in the results.
-
-=head2 delete_value ($name)
-
-Deletes the specified value from the results.
-
-=head2 get_original_value ($name)
-
-Get the original value for the specified field.
-
-=head2 get_post_filter_value ($name)
-
-Get the post-filter value for the specified field.
-
-=head2 get_value ($name)
-
-Returns the value for the specified field.  The value may be different from
-the one originally supplied due to filtering or coercion.
-
-=head2 get_values (@names)
-
-Same concept as C<get_value> but will return a list of respective values in
-the same order in which you provide the names.
-
-=head2 value_count
-
-Returns the number of values in this Results.
-
-=head1 VALID FIELDS
-
-=head2 is_valid ($name)
-
-Returns true if the field is valid.
-
-=head2 valids
-
-Returns a list of keys for which we have valid values.
-
-=head2 valid_values
-
-Returns a hash of valid values in the form of C<name => value>.  This is a
-convenient method for instantiating Moose objects from your verified data.
-
-=head1 INVALID FIELDS
-
-=head2 is_invalid ($name)
-
-Returns true if the specific field is invalid.
-
-=head2 invalids
-
-Returns a list of invalid field names.
-
-=head2 invalid_count
-
-Returns the count of invalid fields in this result.
-
-=head1 MISSING FIELDS
-
-=head2 is_missing ($name)
-
-Returns true if the specified field is missing.
-
-=head2 missings
-
-Returns a list of missing field names.
-
-=head2 missing_count
-
-Returns the count of missing fields in this result.
-
-=head1 FIELDS
-
-=head2 get_field ($name)
-
-Gets the field object, if it exists, for the name provided.
-
-=head2 has_field ($name)
-
-Returns true if the name in question is part of this result object.  This
-should be true for any field that was in the profile.
-
-=head2 set_field ($name)
-
-Sets the field object (you shouldn't be doing this directly) for the name
-provided.
-
 =head1 SERIALIZATION
 
 Data::Verifier uses L<MooseX::Storage::Deferred> to allow quick and easy
@@ -340,16 +253,110 @@ object for the state of any arbitrary fields.  This will not throw any
 exceptions, but it may not return the results you want if you query for
 arbitrary field names.
 
+=head1 ATTRIBUTES
+
+=head2 fields
+
+HashRef of fields in this Results object.
+
+=head1 METHODS
+
+=head2 get_field ($name)
+
+Gets the field object, if it exists, for the name provided.
+
+=head2 has_field ($name)
+
+Returns true if the name in question is part of this result object.  This
+should be true for any field that was in the profile.
+
+=head2 set_field ($name)
+
+Sets the field object (you shouldn't be doing this directly) for the name
+provided.
+
+=head2 get_original_value ($name)
+
+Get the original value for the specified field.
+
+=head2 get_post_filter_value ($name)
+
+Get the post-filter value for the specified field.
+
+=head2 get_value ($name)
+
+Returns the value for the specified field.  The value may be different from
+the one originally supplied due to filtering or coercion.
+
+=head2 get_values (@names)
+
+Same concept as C<get_value> but will return a list of respective values in
+the same order in which you provide the names.
+
+=head2 is_invalid ($name)
+
+Returns true if the specific field is invalid.
+
+=head2 is_missing ($name)
+
+Returns true if the specified field is missing.
+
+=head2 is_valid ($name)
+
+Returns true if the field is valid.
+
+=head2 is_wrong ($name)
+
+Returns true if the value was required and is missing or if the value did not
+pass it's type constraint.  This is a one-stop method for determining if the
+field in question is "wrong".
+
+=head2 invalid_count
+
+Returns the count of invalid fields in this result.
+
+=head2 invalids
+
+Returns a list of invalid field names.
+
+=head2 missing_count
+
+Returns the count of missing fields in this result.
+
+=head2 missings
+
+Returns a list of missing field names.
+
+=head2 success
+
+Returns true or false based on if the verification's success.
+
+=head2 valids
+
+Returns a list of keys for which we have valid values.
+
+=head2 valid_count
+
+Returns the number of valid fields in this Results.
+
+=head2 valid_values
+
+Returns a hash of valid values in the form of C<name => value>.  This is a
+convenient method for instantiating Moose objects from your verified data.
+
 =head1 AUTHOR
 
-Cory G Watson, C<< <gphat at cpan.org> >>
+Cory G Watson <gphat@cpan.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Cold Hard Code, LLC
+This software is copyright (c) 2011 by Cold Hard Code, LLC.
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
 
-See http://dev.perl.org/licenses/ for more information.
